==> pagetree-3.0.0.tar.gz: pagetree/src/Plugin/Block/PageTree.php <==
<?php

namespace Drupal\pagetree\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Language\LanguageInterface;
use Drupal\Core\Language\LanguageManager;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Routing\AdminContext;
use Drupal\Core\Routing\CurrentRouteMatch;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides an page tree block.
 *
 * The block needs to be added to the themes header region to take effect.
 *
 * @Block(
 *   id = "pagetree_block",
 *   admin_label = @Translation("Page Tree Block"),
 * )
 */
class PageTree extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The current user.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $currentUser;

  /**
   * The admin route context.
   *
   * @var \Drupal\Core\Routing\AdminContext
   */
  protected $adminRouteContext;

  /**
   * The current route.
   *
   * @var \Drupal\Core\Routing\CurrentRouteMatch
   */
  protected $currentRoute;

  /**
   * The langauge manager.
   *
   * @var \Drupal\Core\Language\LanguageManager
   */
  protected $languageManager;

  /**
   * Constructs a PageTree Block.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Session\AccountInterface $current_user
   *   The current user.
   * @param \Drupal\Core\Routing\AdminContext $admin_route_context
   *   The admin route context.
   * @param \Drupal\Core\Routing\CurrentRouteMatch $current_route
   *   The current route.
   * @param \Drupal\Core\Language\LanguageManager $language_manager
   *   The langauge manager.
   */
  public function __construct(array $configuration, string $plugin_id, $plugin_definition, AccountInterface $current_user, AdminContext $admin_route_context, CurrentRouteMatch $current_route, LanguageManager $language_manager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->currentUser = $current_user;
    $this->adminRouteContext = $admin_route_context;
    $this->currentRoute = $current_route;
    $this->languageManager = $language_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_user'),
      $container->get('router.admin_context'),
      $container->get('current_route_match'),
      $container->get('language_manager'),
    );
  }

  /**
   * Builds the page tree block.
   *
   * @return array
   *   The render array.
   */
  public function build() {
    $build = [];

    // If user is logged in and has permission to edit page nodes,
    // enable edit mode.
    if ($this->currentUser->hasPermission('use pagetree') && !$this->adminRouteContext->isAdminRoute()) {
      // Attach library for editing.
      $build['#attached']['library'] = ['pagetree/pagetree'];

      // Set values for displaying page tree.
      $build['#theme'] = 'pagetree';
      $build['#attached']['drupalSettings']['pagetree']['currentNode'] = $this->currentRoute->getRawParameter('node');
      $build['#attached']['drupalSettings']['pagetree']['currentLanguage'] = $this->languageManager->getcurrentLanguage(LanguageInterface::TYPE_CONTENT)->getId();
      $build['#attached']['drupalSettings']['pagetree']['defaultLanguage'] = $this->languageManager->getDefaultLanguage()->getId();
    }
    // Prevent block from being cached.
    $build['#cache'] = [
      'contexts' => ['route'],
    ];

    return $build;
  }

}

==> pagetree-3.0.1.tar.gz: pagetree/src/Plugin/Block/PageTree.php <==
<?php

namespace Drupal\pagetree\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Language\LanguageManager;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Routing\AdminContext;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides an page tree block.
 *
 * The block needs to be added to the themes header region to take effect.
 *
 * @Block(
 *   id = "pagetree_block",
 *   admin_label = @Translation("Page Tree Block"),
 * )
 */
class PageTree extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * Constructs a PageTree Block.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\Core\Session\AccountInterface $currentUser
   *   The current user.
   * @param \Drupal\Core\Routing\AdminContext $adminRouteContext
   *   The admin route context.
   * @param \Drupal\Core\Language\LanguageManager $languageManager
   *   The langauge manager.
   */
  public function __construct(
    array $configuration,
  string $plugin_id,
  $plugin_definition,
  protected AccountInterface $currentUser,
  protected AdminContext $adminRouteContext,
  protected LanguageManager $languageManager
  ) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('current_user'),
      $container->get('router.admin_context'),
      $container->get('language_manager'),
    );
  }

  /**
   * Builds the page tree block.
   *
   * @return array
   *   The render array.
   */
  public function build() {
    $build = [];

    // If user is logged in and has permission to edit page nodes,
    // enable edit mode.
    if ($this->currentUser->hasPermission('use pagetree')) {
      // Attach library for editing.
      $build['#attached']['library'] = ['pagetree/pagetree'];

      // Set values for displaying page tree.
      $build['#theme'] = 'pagetree';
      $build['#attached']['drupalSettings']['pagetree']['defaultLanguage'] = $this->languageManager->getDefaultLanguage()->getId();
    }
    // Cache per route and permissions.
    $build['#cache'] = [
      'contexts' => ['user.permissions'],
    ];

    return $build;
  }

}
